@@ -156,10 +156,10 @@ class DummyBenchmark(BaseBenchmark):
                                             video_path=self.config["video_root"]+video_name)
             ################## main loop ########################
             try:
-                for i in range(150):
+                for i in range(self._max_duration):
                 # while True:
                 # 评估
-                    if self.env.ego_veh_state.x() > 250:
+                    if self.env.ego_veh_state.x() > self._destination_x_range[0]:
                         break
 
 
