@@ -7,8 +7,11 @@ import numpy as np
 
 import spider
 import spider.elements as elm
+import spider.elements.vehicle
 from spider.elements import TrackingBoxList, OccupancyGrid2D, RoutedLocalMap, VehicleState, Trajectory
 
+from spider.control import SimpleController
+
 # from spider.elements import Location, Rotation, Transform,
 
 '''
@@ -49,6 +52,8 @@ class HighwayEnvInterface:
 
         self._routed_local_map = None
 
+        self._controller = SimpleController()
+
     # def observe_env(self):
     #     obs, info = self._env.
     @property
@@ -62,7 +67,8 @@ class HighwayEnvInterface:
     def reset(self):
         # todo: qzl: 想一想有没有什么更多的需要reset的
         self._routed_local_map = None
-        return self._env.reset()
+        obs,info = self._env.reset()
+        return self.wrap_observation(obs)
 
     def step(self, action) -> Tuple["Observation", float, bool, bool, dict]:
         """
@@ -106,7 +112,7 @@ class HighwayEnvInterface:
 
         return ego_veh_state, perception, local_map
 
-    def convert_to_action(self, planner_output, gain_coef=1.1, wheelbase=3.0):
+    def convert_to_action(self, planner_output, ego_veh_state:VehicleState=None):
         if planner_output is None:
             raise AssertionError("The planner outputs NO results. Please check whether it can find a valid solution, and it is recommended to add a fallback trajectory generation scheme.")
 
@@ -114,42 +120,22 @@ class HighwayEnvInterface:
             raise AssertionError("not supported now. Please change the environment action type into ContinuousAction.")
 
         if self.output_flag == spider.OUTPUT_TRAJECTORY:  # 轨迹
-            # todo: 注意，这里没有用控制算法出控制量，直接用差分法出控制量按道理是不对的，以后要改掉
-            # todo: 现在没有统一轨迹中,a的定义是从t0开始还是t1开始。目前默认是从t0开始，所以下一刻要执行的是t1的
-            if len(planner_output.a) > 0:
-                acc = gain_coef * planner_output.a[1]
-            else:
-                try:
-                    acc = gain_coef * (planner_output.v[1] - planner_output.v[0]) / planner_output.dt
-                except:
-                    raise AssertionError("The trajectory lacks the acceleration information!")
-
-            if len(planner_output.steer) > 0:
-                steer = gain_coef * planner_output.steer[1]
-            else:
-                try:
-                    steer = gain_coef * np.arctan(planner_output.curvature[1]*wheelbase) / planner_output.dt
-                except:
-                    raise AssertionError("The trajectory lacks the steer information!")
-            # if len(planner_output.a) == 0 or len(planner_output.steer) == 0:
-            #     raise AssertionError("The trajectory lacks the acceleration or steering_angle information!")
-            # else:
-            #     acc, steer = gain_coef*planner_output.a[1], gain_coef*planner_output.steer[1]
+            planner_output:Trajectory
+            acc, steer = self._controller.get_control(planner_output, ego_veh_state)
             return acc, steer
-
         else:  # 控制量
             raise NotImplementedError("control not supported now...")
 
-    def conduct_trajectory(self, trajectory):
-        action = self.convert_to_action(trajectory, trajectory.dt)
+    def conduct_trajectory(self, trajectory:Trajectory, ego_veh_state:VehicleState=None):
+        action = self.convert_to_action(trajectory, ego_veh_state)
         return self._env.step(action)
 
-    def conduct_output(self, planner_output):
+    def conduct_output(self, planner_output, ego_veh_state:VehicleState=None):
         '''
         qzl: 应该写成直接执行动作呢还是写成输出对应格式的动作呢？
         '''
         if self.output_flag == spider.OUTPUT_TRAJECTORY:  # 轨迹
-            return self.conduct_trajectory(planner_output)
+            return self.conduct_trajectory(planner_output, ego_veh_state)
         else:  # 控制量
             raise NotImplementedError("not supported now...")
 
@@ -182,7 +168,7 @@ class HighwayEnvInterface:
     #     necessary_keys = ["presence", "x", "y", "vx", "vy","heading","cos_h", "sin_h"]
     #     for key in necessary_keys:
     #         if key in features:
-    #             idx = features.index(key)
+    #             idx = features.record_index(key)
     #             self.kine_feature_index_mapping[key] = idx
     #     assert "x" in self.kine_feature_index_mapping and "y" in self.kine_feature_index_mapping
 
@@ -223,8 +209,8 @@ class HighwayEnvInterface:
         ego_info: dict = self._get_veh_info_dict(observation[0], necessary_feat)
         loc = elm.Location(ego_info["x"], ego_info["y"], 0.)
         rot = elm.Rotation(0., ego_info["heading"], 0.)
-        velocity = elm.Vector3D(ego_info["vx"], ego_info["vy"], 0.)
-        ego_state = VehicleState(elm.Transform(loc, rot), velocity, elm.Vector3D())
+        velocity = spider.elements.vehicle.Vector3D(ego_info["vx"], ego_info["vy"], 0.)
+        ego_state = VehicleState(elm.Transform(loc, rot), velocity, spider.elements.vehicle.Vector3D())
         return ego_state
 
     def _wrap_kine2box(self, observation) -> TrackingBoxList:
@@ -233,7 +219,7 @@ class HighwayEnvInterface:
         tbox_list = TrackingBoxList()
         for i, veh_info_vector in enumerate(observation):
             if i == 0:
-                # i=0 是自车，不需要加入BoundingBox
+                # index=0 是自车，不需要加入BoundingBox
                 continue
 
             veh_info = self._get_veh_info_dict(veh_info_vector, necessary_feat)
