@@ -57,6 +57,24 @@ COLLISION_CHECKER_AABB = _assignment()
 COLLISION_CHECKER_DISK = _assignment()
 COLLISION_CHECKER_OCC = _assignment()
 
+####################### DATA ######################
+# for data closed-loop engine
+DATA_FORMAT_JSON = _assignment(0) # 将log buffer以json格式存储
+DATA_FORMAT_TENSOR = _assignment() # 将log buffer以tensor格式存储
+DATA_FORMAT_RAW = _assignment() # 将log buffer以原始数据格式存储
+
+DATA_TYPE_LOG = _assignment(0)
+DATA_TYPE_EXP = _assignment()
+
+DATA_GT_PLAN = _assignment(0)  # 真值数据为plan
+DATA_GT_TRACE = _assignment()  # 真值数据为trace
+
+
+
+# LOAD_TYPE_DATALOADER = _assignment(0) # 读取数据 并 转化为dataloader
+# LOAD_TYPE_RAW = _assignment() # 读取数据 并 保持原始数据格式
+
+
 ####################### RL ######################
 # NN MODE FLAG
 NN_TRAIN_MODE = _assignment(0)
